pub enum Error {
ExpectedBytes(u32),
ExpectedRange(RangeInclusive<u32>),
InvalidUtf8(FromUtf8Error),
TooLarge {
needed_bytes: u32,
max_bytes: u32,
},
InvalidChar,
}Variants
ExpectedBytes(u32)
The bytecode provided is too short. This should only ever happen if the bytecode is outdated, or something went wrong when generating it.
ExpectedRange(RangeInclusive<u32>)
Expected a value in a given range, e.g., bools must be between 0 and 1.
InvalidUtf8(FromUtf8Error)
Parsing a string resulted in invalid utf8.
TooLarge
See Size.
This error is generated when into_bytes is called
on a variable-length struct with >= 2^S items
InvalidChar
Encountered an invalid utf8 sequence